@@ -1,5 +1,6 @@
 from kitconcept import api
 from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
+from plone.app.multilingual.testing import PLONE_APP_MULTILINGUAL_FIXTURE
 from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
 from plone.app.testing import applyProfile
 from plone.app.testing import FunctionalTesting
@@ -17,7 +18,7 @@ import kitconcept.contentcreator
 
 class ContentcreatorCoreLayer(PloneSandboxLayer):
 
-    defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)
+    defaultBases = (PLONE_APP_MULTILINGUAL_FIXTURE,)
 
     def setUpZope(self, app, configurationContext):
         self.loadZCML(package=kitconcept.contentcreator)
